@@ -1,5 +1,6 @@
 import pyqtgraph as _pg
-_pg.setConfigOption('imageAxisOrder', 'row-major')
+
+_pg.setConfigOption("imageAxisOrder", "row-major")
 # Be sure to register pgparams
 from .params.prjparam import PrjParam
 from .params import pgregistered as _
@@ -10,4 +11,5 @@ from . import fns, widgets
 
 from .constants import PrjEnums
 import logging as _logging
-_logging.addLevelName(PrjEnums.LOG_LVL_ATTN, 'ATTN')
+
+_logging.addLevelName(PrjEnums.LOG_LVL_ATTN, "ATTN")
