@@ -1064,3 +1064,39 @@ def makeDummySignal(obj, sigName: str, capture=False):
         yield newSig
     finally:
         setattr(obj, sigName, oldSig)
+
+
+def getAnyPgColormap(name, forceExist=False):
+    """
+    Pyqtgraph allows file, matplotlib, or colorcet cmaps but doesn't allow getting from
+    an arbitrary source. This simply shims access to ``pg.colormap.get`` which tries
+    all sources each time a source-specific ``get`` fails.
+    :param name: passed to ``pg.colormap.get``
+    """
+    for source in None, "matplotlib", "colorcet":
+        try:
+            cmap = pg.colormap.get(name, source=source)
+        except FileNotFoundError:
+            # For None source when local file doesn't exist
+            cmap = None
+        if cmap is not None:
+            return cmap
+    # cmap = None at this point
+    if forceExist:
+        raise ValueError(
+            f"'{colormap}' was not recognized among the available"
+            f" options. Must be one of:\n{fns.listAllPgColormaps()}"
+        )
+    # else
+    return None
+
+
+def listAllPgColormaps():
+    """``Shims pg.colormap.listMaps`` to list all colormaps (i.e. for all sources)"""
+    maps = []
+    for source in None, "matplotlib", "colorcet":
+        nextMaps = pg.colormap.listMaps(source)
+        for curMap in nextMaps:
+            if curMap not in maps:
+                maps.append(curMap)
+    return maps
