@@ -14,9 +14,6 @@ def _rescale(data, min_, max_):
     return (data.astype(float) - min_) / rng
 
 
-_specialKeys = ["name", "value", "helpText", "pType"]
-
-
 class _UNSPECIFIED_DEFAULT:
     pass
 
@@ -154,12 +151,12 @@ class PrjParam:
         return numericVals
 
     def __getitem__(self, item):
-        if item in _specialKeys:
+        if item in self._fields:
             return getattr(self, item)
         return self.opts[item]
 
     def __setitem__(self, key, value):
-        if key in _specialKeys:
+        if key in self._fields:
             setattr(self, key, value)
         else:
             self.opts[key] = value
@@ -172,11 +169,16 @@ class PrjParam:
                 raise
             return default
 
+    @property
+    def _fields(self):
+        excludeFields = {"group", "opts"}
+        return [field for field in self.__dict__ if field not in excludeFields]
+
     def keys(self):
-        return list(self.opts.keys()) + _specialKeys
+        return self._fields + list(self.opts.keys())
 
     def __contains__(self, item):
-        return item in _specialKeys or item in self.opts
+        return item in self._fields or item in self.opts
 
     def addHelpText(self, prependText="", postfixText="", replace=True, newline="<br>"):
         helpText = self.helpText
