@@ -3,9 +3,9 @@ All API discrepancies between different systems, python versions, etc. should be
 """
 import sys
 
-__all__ = ['typing_extensions']
+__all__ = ["typing_extensions"]
 
 if sys.version_info < (3, 8):
     import typing_extensions
 else:
-    import typing as typing_extensions
\ No newline at end of file
+    import typing as typing_extensions
