@@ -28,6 +28,8 @@ from utilitys.fns import (
     hookupParamWidget,
     timedExec,
     forceRichText,
+    getAnyPgColormap,
+    listAllPgColormaps,
 )
 from utilitys.misc import CompositionMixin
 from utilitys.typeoverloads import FilePath
@@ -881,12 +883,17 @@ class CompositorLegend(pg.LegendItem):
 
 
 class MaskCompositor(ImageViewer):
+    _cachedCmapLimits = None
+
     def __init__(self, img: np.ndarray = None):
         super().__init__()
         # -----
         # Create properties
         # -----
         self.masksParam = getParamChild(self.toolsEditor.params, "Overlays")
+        if self._cachedCmapLimits is None:
+            # Set at class level to cache for new instances too
+            type(self)._cachedCmapLimits = listAllPgColormaps()
 
         self.legend = CompositorLegend(
             offset=(5, 5), horSpacing=5, brush="ccce", pen="k"
@@ -920,7 +927,9 @@ class MaskCompositor(ImageViewer):
 
         with nameFormatter.set(newFmt):
             self.propertiesProc = self.toolsEditor.registerFunc(
-                self.setOverlayProperties, runOpts=params.RunOpts.ON_CHANGED
+                self.setOverlayProperties,
+                runOpts=params.RunOpts.ON_CHANGED,
+                colormap=dict(limits=self._cachedCmapLimits),
             )
             self.toolsEditor.registerFunc(self.save)
             self.toolsEditor.registerFunc(
@@ -971,7 +980,7 @@ class MaskCompositor(ImageViewer):
         self._updateLegendPos()
 
     def _addRecord(self, rec: pd.Series, update=True):
-        self.recordDf = self.recordDf.append(rec)
+        self.recordDf = pd.concat([self.recordDf, rec.to_frame().T], axis=0)
         self.curZ += 1
 
         self._addItemCtrls(rec)
@@ -1118,7 +1127,6 @@ class MaskCompositor(ImageViewer):
         if updateOverlays:
             self._updateGraphics()
 
-    @dynamicDocstring(cmapVals=pg.colormap.listMaps())
     def setOverlayProperties(
         self, colormap="magma", opacity=0.6, fullLabelMapColors=False
     ):
@@ -1126,7 +1134,6 @@ class MaskCompositor(ImageViewer):
         Sets overlay properties
         :param colormap:
           pType: popuplineeditor
-          limits: {cmapVals}
         :param opacity:
           limits: [0,1]
           step: 0.1
@@ -1136,10 +1143,7 @@ class MaskCompositor(ImageViewer):
           ignore: True
         """
         maskIdxs = self.recordDf["isMask"].to_numpy(bool)
-        try:
-            cmap = pg.colormap.get(colormap)
-        except FileNotFoundError:
-            cmap = pg.colormap.get(colormap, source="matplotlib")
+        cmap = getAnyPgColormap(colormap)
         labelValues = self.scatterSer.index.values
         if fullLabelMapColors:
             labelValues = np.union1d(labelValues, self.labelToNameMapping.index.values)
